@@ -1,4 +1,5 @@
 # pylint: disable=no-member, protected-access
+import sqlglot.constants as c
 import sqlglot.expressions as exp
 from sqlglot.generator import Generator
 from sqlglot.helper import RegisteringMeta, csv, list_get
@@ -326,11 +327,36 @@ class Hive(Dialect):
             return None
         return time_format
 
-    def _fileformat_sql(self, expression):
-        file_format = self.sql(expression, "this").replace(self.quote, "")
-        if file_format:
-            return f"STORED AS {file_format}"
-        return ""
+    def _properties_sql(self, expression):
+        expression = expression.copy()
+        properties = expression.args["expressions"]
+
+        stored_as = ""
+        partitioned_by = ""
+
+        for p in properties:
+            if p.text("this").upper() == c.FORMAT:
+                stored_as = p
+            if isinstance(p.args["value"], exp.Schema):
+                partitioned_by = p
+
+        if partitioned_by:
+            properties.remove(partitioned_by)
+            partitioned_by = self.seg(
+                f"PARTITIONED BY {self.sql(partitioned_by.args['value'])}"
+            )
+        if stored_as:
+            properties.remove(stored_as)
+            stored_as = self.seg(f"STORED AS {stored_as.text('value').upper()}")
+
+        return (
+            f"{partitioned_by}{stored_as}{self.properties('TBLPROPERTIES', expression)}"
+        )
+
+    def _property_sql(self, expression):
+        key = expression.text("this")
+        value = self.sql(expression, "value")
+        return f"'{key}' = {value}"
 
     def _str_to_unix(self, expression):
         return f"UNIX_TIMESTAMP({csv(self.sql(expression, 'this'), Hive._time_format(self, expression))})"
@@ -367,7 +393,8 @@ class Hive(Dialect):
         exp.DateAdd: lambda self, e: f"DATE_ADD({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.DateDiff: lambda self, e: f"DATEDIFF({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.DateStrToDate: lambda self, e: self.sql(e, "this"),
-        exp.FileFormat: _fileformat_sql,
+        exp.Properties: _properties_sql,
+        exp.Property: _property_sql,
         exp.If: _if_sql,
         exp.ILike: _no_ilike_sql,
         exp.Join: _unnest_to_explode_sql,
@@ -499,12 +526,6 @@ class Presto(Dialect):
             sql = f"{sql} WITH TIME ZONE"
         return sql
 
-    def _fileformat_sql(self, expression):
-        file_format = self.sql(expression, "this").replace(self.quote, "")
-        if file_format:
-            return f"WITH (FORMAT = '{file_format}')"
-        return ""
-
     def _date_parse_sql(self, expression):
         return f"DATE_PARSE({self.sql(expression, 'this')}, '%Y-%m-%d %H:%i:%s')"
 
@@ -512,6 +533,20 @@ class Presto(Dialect):
         regex = "(\w)(\w*)"  # pylint: disable=anomalous-backslash-in-string
         return f"REGEXP_REPLACE({self.sql(expression, 'this')}, '{regex}', x -> UPPER(x[1]) || LOWER(x[2]))"
 
+    def _schema_sql(self, expression):
+        if isinstance(expression.parent, exp.Property):
+            columns = ", ".join(
+                f"'{c.text('this')}'" for c in expression.args["expressions"]
+            )
+            return f"ARRAY[{columns}]"
+
+        for schema in expression.parent.find_all(exp.Schema):
+            if isinstance(schema.parent, exp.Property):
+                expression = expression.copy()
+                expression.args["expressions"].extend(schema.args["expressions"])
+
+        return self.schema_sql(expression)
+
     def _quantile_sql(self, expression):
         self.unsupported("Presto does not support exact quantiles")
         return f"APPROX_PERCENTILE({self.sql(expression, 'this')}, {self.sql(expression, 'quantile')})"
@@ -564,7 +599,6 @@ class Presto(Dialect):
         exp.DateAdd: lambda self, e: f"""DATE_ADD({self.sql(e, 'unit') or "'day'"}, {self.sql(e, 'expression')}, {self.sql(e, 'this')})""",
         exp.DateDiff: lambda self, e: f"""DATE_DIFF({self.sql(e, 'unit') or "'day'"}, {self.sql(e, 'expression')}, {self.sql(e, 'this')})""",
         exp.DateStrToDate: lambda self, e: f"DATE_PARSE({self.sql(e, 'this')}, '%Y-%m-%d')",
-        exp.FileFormat: _fileformat_sql,
         exp.If: _if_sql,
         exp.ILike: _no_ilike_sql,
         exp.Initcap: _initcap_sql,
@@ -572,6 +606,7 @@ class Presto(Dialect):
         exp.Lateral: _explode_to_unnest_sql,
         exp.Quantile: _quantile_sql,
         exp.RegexLike: lambda self, e: f"REGEXP_LIKE({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
+        exp.Schema: _schema_sql,
         exp.StrPosition: _str_position_sql,
         exp.StrToTime: lambda self, e: f"DATE_PARSE({self.sql(e, 'this')}, {self.format_time(e)})",
         exp.StrToUnix: lambda self, e: f"TO_UNIXTIME(DATE_PARSE({self.sql(e, 'this')}, {self.format_time(e)}))",
