@@ -252,7 +252,7 @@ class Create(Expression):
         "kind": True,
         "expression": False,
         "exists": False,
-        "file_format": False,
+        "properties": False,
         "temporary": False,
         "replace": False,
         "engine": False,
@@ -312,10 +312,6 @@ class Except(Expression):
     arg_types = {"this": True, "expression": True, "distinct": False}
 
 
-class FileFormat(Expression):
-    pass
-
-
 class From(Expression):
     arg_types = {"expressions": True}
 
@@ -417,6 +413,14 @@ class Ordered(Expression):
     arg_types = {"this": True, "desc": False}
 
 
+class Properties(Expression):
+    arg_types = {"expressions": True}
+
+
+class Property(Expression):
+    arg_types = {"this": True, "value": True}
+
+
 class Table(Expression):
     arg_types = {"this": True, "db": False}
 
@@ -447,7 +451,7 @@ class Values(Expression):
 
 
 class Schema(Expression):
-    arg_types = {"this": True, "expressions": True}
+    arg_types = {"this": False, "expressions": True}
 
 
 class Select(Expression):
